import React from 'react'
import { SymbolSearch, SymbolMenu, SymbolFacebook } from './svgs'
import { Search } from './search'

export function Html({
  prehead = null,
  head = null,
  metadata = {},
  canonicalURL,
  config,
  children,
  bodyClassName,
}) {
  return (
    <html lang="en">
      <head>
        <meta httpEquiv="Content-Type" content="text/html; charset=UTF-8" />
        {prehead}
        <meta
          name="viewport"
          content="width=device-width, initial-scale=1, maximum-scale=1.0"
        />
        <title>{metadata.title || 'Radioklub OK1KVK'}</title>

        <link rel="canonical" href={canonicalURL} />
        <meta
          property="og:title"
          content={metadata.title || 'Radioklub OK1KVK'}
        />
        <meta property="og:locale" content="cs_CZ" />
        <meta property="og:url" content={canonicalURL} />
        <meta property="og:site_name" content="ok1kvk.cz" />
        <meta property="fb:app_id" content="1419886504744454" />

        <link
          href="https://fonts.googleapis.com/css?family=Roboto&subset=latin,latin-ext"
          rel="stylesheet"
          type="text/css"
        />
        <link
          href={`${config.baseurl}/theme/style.css?v=2`}
          type="text/css"
          rel="stylesheet"
          media="screen,projection"
        />
        <link
          href={`${config.baseurl}/theme/highlight.css`}
          type="text/css"
          rel="stylesheet"
          media="screen,projection"
        />
        <link
          href={`${config.baseurl}/theme/lightbox2/dist/css/lightbox.min.css`}
          type="text/css"
          rel="stylesheet"
          media="screen,projection"
        />

        <script
          src={`${config.baseurl}/theme/js/jquery-1.12.0.min.js`}
        ></script>

        <link
          rel="apple-touch-icon"
          sizes="57x57"
          href={`${config.baseurl}/theme/favicons/apple-touch-icon-57x57.png?v=3`}
        />
        <link
          rel="apple-touch-icon"
          sizes="60x60"
          href={`${config.baseurl}/theme/favicons/apple-touch-icon-60x60.png?v=3`}
        />
        <link
          rel="apple-touch-icon"
          sizes="72x72"
          href={`${config.baseurl}/theme/favicons/apple-touch-icon-72x72.png?v=3`}
        />
        <link
          rel="apple-touch-icon"
          sizes="76x76"
          href={`${config.baseurl}/theme/favicons/apple-touch-icon-76x76.png?v=3`}
        />
        <link
          rel="apple-touch-icon"
          sizes="114x114"
          href={`${config.baseurl}/theme/favicons/apple-touch-icon-114x114.png?v=3`}
        />
        <link
          rel="apple-touch-icon"
          sizes="120x120"
          href={`${config.baseurl}/theme/favicons/apple-touch-icon-120x120.png?v=3`}
        />
        <link
          rel="apple-touch-icon"
          sizes="144x144"
          href={`${config.baseurl}/theme/favicons/apple-touch-icon-144x144.png?v=3`}
        />
        <link
          rel="apple-touch-icon"
          sizes="152x152"
          href={`${config.baseurl}/theme/favicons/apple-touch-icon-152x152.png?v=3`}
        />
        <link
          rel="apple-touch-icon"
          sizes="180x180"
          href={`${config.baseurl}/theme/favicons/apple-touch-icon-180x180.png?v=3`}
        />
        <link
          rel="icon"
          type="image/png"
          href={`${config.baseurl}/theme/favicons/favicon-32x32.png?v=3`}
          sizes="32x32"
        />
        <link
          rel="icon"
          type="image/png"
          href={`${config.baseurl}/theme/favicons/android-chrome-192x192.png?v=3`}
          sizes="192x192"
        />
        <link
          rel="icon"
          type="image/png"
          href={`${config.baseurl}/theme/favicons/favicon-96x96.png?v=3`}
          sizes="96x96"
        />
        <link
          rel="icon"
          type="image/png"
          href={`${config.baseurl}/theme/favicons/favicon-16x16.png?v=3`}
          sizes="16x16"
        />
        <link
          rel="manifest"
          href={`${config.baseurl}/theme/favicons/manifest.json?v=3`}
        />
        <link
          rel="mask-icon"
          href={`${config.baseurl}/theme/favicons/safari-pinned-tab.svg?v=3`}
          color="#0288d1"
        />
        <link
          rel="shortcut icon"
          href={`${config.baseurl}/theme/favicons/favicon.ico?v=3`}
        />
        <meta name="msapplication-TileColor" content="#2d89ef" />
        <meta
          name="msapplication-TileImage"
          content={`${config.baseurl}/theme/favicons/mstile-144x144.png?v=3`}
        />
        <meta
          name="msapplication-config"
          content={`${config.baseurl}/theme/favicons/browserconfig.xml?v=3`}
        />
        <meta name="theme-color" content="#0288d1" />
        {config.devel ? (
          <script
            src={`${config.baseurl}/theme/js/socket.io-1.4.5.js`}
          ></script>
        ) : null}
        {head}
      </head>
      <body className={bodyClassName}>{children}</body>
    </html>
  )
}
